@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #include <config.h>
@@ -193,7 +193,7 @@ e_cal_util_parse_ics_string (const char *string)
 							icalcomponent_merge_component (icalcomp, tmp);
 						else
 							icalcomp = tmp;
-					} else 
+					} else
 						g_warning ("Could not merge the components, the component is either invalid or not a toplevel component \n");
 
 					g_string_free (comp_str, TRUE);
@@ -323,7 +323,7 @@ struct alarm_occurrence_data {
 	time_t start;
 	time_t end;
 	ECalComponentAlarmAction *omit;
-	
+
 	/* This is what we compute */
 	GSList *triggers;
 	int n_triggers;
@@ -366,7 +366,7 @@ add_alarm_occurrences_cb (ECalComponent *comp, time_t start, time_t end, gpointe
 		time_t dur_time;
 		time_t occur_time, trigger_time;
 		int i;
-		
+
 		auid = l->data;
 		alarm = e_cal_component_get_alarm (comp, auid);
 		g_assert (alarm != NULL);
@@ -382,7 +382,7 @@ add_alarm_occurrences_cb (ECalComponent *comp, time_t start, time_t end, gpointe
 		}
 		if (aod->omit[i] != -1)
 			continue;
-		
+
 		if (trigger.type != E_CAL_COMPONENT_ALARM_TRIGGER_RELATIVE_START
 		    && trigger.type != E_CAL_COMPONENT_ALARM_TRIGGER_RELATIVE_END)
 			continue;
@@ -453,7 +453,7 @@ generate_absolute_triggers (ECalComponent *comp, struct alarm_occurrence_data *a
 		time_t occur_start, occur_end;
 		icaltimezone *zone;
 		int i;
-		
+
 		auid = l->data;
 		alarm = e_cal_component_get_alarm (comp, auid);
 		g_assert (alarm != NULL);
@@ -550,7 +550,7 @@ compare_alarm_instance (gconstpointer a, gconstpointer b)
  * @comp: The #ECalComponent to generate alarms from.
  * @start: Start time.
  * @end: End time.
- * @omit: 
+ * @omit: Alarm types to omit
  * @resolve_tzid: Callback for resolving timezones
  * @user_data: Data to be passed to the resolve_tzid callback
  * @default_timezone: The timezone used to resolve DATE and floating DATE-TIME
@@ -599,6 +599,8 @@ e_cal_util_generate_alarms_for_comp (ECalComponent *comp,
 	/* We add the ABSOLUTE triggers separately */
 	generate_absolute_triggers (comp, &aod, resolve_tzid, user_data, default_timezone);
 
+	cal_obj_uid_list_free (alarm_uids);
+
 	if (aod.n_triggers == 0)
 		return NULL;
 
@@ -617,7 +619,7 @@ e_cal_util_generate_alarms_for_comp (ECalComponent *comp,
  * @comps: List of #ECalComponent's.
  * @start: Start time.
  * @end: End time.
- * @omit: 
+ * @omit: Alarm types to omit
  * @comp_alarms: List to be returned
  * @resolve_tzid: Callback for resolving timezones
  * @user_data: Data to be passed to the resolve_tzid callback
@@ -835,6 +837,14 @@ e_cal_util_component_has_organizer (icalcomponent *icalcomp)
 	return prop ? TRUE : FALSE;
 }
 
+/**
+ * e_cal_util_component_has_attendee:
+ * @icalcomp: An #icalcomponent.
+ *
+ * Checks if an #icalcomponent has any attendees.
+ *
+ * Return value: TRUE if there are attendees, FALSE if not.
+ */
 gboolean
 e_cal_util_component_has_attendee (icalcomponent *icalcomp)
 {
@@ -940,7 +950,7 @@ e_cal_util_event_dates_match (icalcomponent *icalcomp1, icalcomponent *icalcomp2
 			return FALSE;
 	}
 
-	
+
 
 	/* now match the timezones */
 	if (!(!c1_dtstart.zone && !c2_dtstart.zone) ||
